Index: trunk/ippToPsps/jython/stackbatch.py
===================================================================
--- trunk/ippToPsps/jython/stackbatch.py	(revision 37450)
+++ trunk/ippToPsps/jython/stackbatch.py	(revision 37475)
@@ -161,5 +161,5 @@
 
        self.dropTableVerbose("StackObjectThin")
-       self.dropTableVerbose("StackObjectRaw")
+       self.dropTableVerbose("StackObjectAttributes")
        
        self.dropTableVerbose("StackModelFitExtra")
@@ -169,7 +169,7 @@
 
        self.dropTableVerbose("StackApFlx")
-       self.dropTableVerbose("StackApFlxFull")
-       self.dropTableVerbose("StackApFlxFullC1")
-       self.dropTableVerbose("StackApFlxFullC2")
+       self.dropTableVerbose("StackApFlxEGUnc")
+       self.dropTableVerbose("StackApFlxEGCon6")
+       self.dropTableVerbose("StackApFlxEGCon8")
 
        self.dropTableVerbose("StackPetrosian")
@@ -374,9 +374,9 @@
 
     '''
-    Populates the StackObjectRaw table
-    '''
-    def populateStackObjectRaw(self):
-
-        tablename = "StackObjectRaw"
+    Populates the StackObjectAttributes table
+    '''
+    def populateStackObjectAttributes(self):
+
+        tablename = "StackObjectAttributes"
 
         self.logger.infoPair("Procesing table", tablename)
@@ -558,5 +558,5 @@
         # insert detection information for each filter based on the
         # DVO contents.  Since I already have extracted
         # StackObjectRaw, this is probably faster using that table:
         sqlLine = sqlUtility("UPDATE " + tablename + " AS a, " + self.scratchDb.dvoDetectionTable + " as b SET")
         sqlLine.group("a." + filter + model + "Mag",       "a." + filter + model + "Mag + b.zp")
@@ -592,5 +592,5 @@
 
         # insert detection information for each filter based on the DVO contents
-        sqlLine = sqlUtility("UPDATE " + tablename + " AS a, StackObjectThin as b, StackObjectRaw as c SET ")
+        sqlLine = sqlUtility("UPDATE " + tablename + " AS a, StackObjectThin as b, StackObjectAttributes as c SET ")
         sqlLine.group(extR, rawR + " - (" + extR + " - " + rawX + ")*" + rawS + " / 3600.0 / cos(radians(" + rawD + "))")
         sqlLine.group(extD, rawD + " + (" + extD + " - " + rawY + ")*" + rawS + " / 3600.0")
@@ -699,7 +699,7 @@
 
         for filter in self.filters:
-            self.populateStackApFlxFilter(tablename, "", filter)
-            self.populateStackApFlxFilter(tablename, "C1", filter)
-            self.populateStackApFlxFilter(tablename, "C2", filter)
+            self.populateStackApFlxFilter(tablename, "Unc", filter)
+            self.populateStackApFlxFilter(tablename, "Con6", filter)
+            self.populateStackApFlxFilter(tablename, "Con8", filter)
 
         self.deleteRowsWithNoStackData(tablename)
@@ -707,9 +707,9 @@
 
     '''
-    Populates the StackApFlxFull table
-    '''
-    def populateStackApFlxFull(self, version):
-
-        tablename = "StackApFlxFull" + version
+    Populates the StackApFlxEG table
+    '''
+    def populateStackApFlxEG(self, version):
+
+        tablename = "StackApFlxEG" + version
 
         if self.config.camera == "simtest":
@@ -730,5 +730,5 @@
 
     '''
-    Updates aperture fluxes for StackApFkx table
+    Updates aperture fluxes for StackApFlx table
     '''
     def populateStackApFlxFilter(self, tablename, version, filter):
@@ -737,13 +737,13 @@
 
         # order of the 3 convolutions is fixed (raw, C1, C2) = (1, 2, 3)
-        if version == "":   
+        if version == "Unc":   
             psfCondition = "(b.table_index % 3 = 1)"
             prefix = ""
-        if version == "C1": 
+        if version == "Con6": 
             psfCondition = "(b.table_index % 3 = 2)"
-            prefix = "c1"
-        if version == "C2": 
+            prefix = "c6"
+        if version == "Con8": 
             psfCondition = "(b.table_index % 3 = 0)" 
-            prefix = "c2"
+            prefix = "c8"
 
         if prefix == "none":
@@ -1053,5 +1053,5 @@
         self.populateStackObjectThin()
 
-        self.populateStackObjectRaw()
+        self.populateStackObjectAttributes()
 
         if self.stackType != "NIGHTLY_STACK":
@@ -1070,7 +1070,7 @@
             self.populateStackApFlx()
 
-            self.populateStackApFlxFull("")
-            self.populateStackApFlxFull("C1")
-            self.populateStackApFlxFull("C2")
+            self.populateStackApFlxEG("Unc")
+            self.populateStackApFlxEG("Con6")
+            self.populateStackApFlxEG("Con8")
 
         # delete rows with no content. for the other tables, this is done in 
@@ -558,5 +558,5 @@
         # insert detection information for each filter based on the
         # DVO contents.  Since I already have extracted
-        # StackObjectRaw, this is probably faster using that table:
+        # StackObjectAttributes, this is probably faster using that table:
         sqlLine = sqlUtility("UPDATE " + tablename + " AS a, " + self.scratchDb.dvoDetectionTable + " as b SET")
         sqlLine.group("a." + filter + model + "Mag",       "a." + filter + model + "Mag + b.zp")
